@@ -1,32 +1,37 @@
 import asyncio
 import random as random_module
+from typing import AsyncIterable, AsyncIterator
 
-from aiostream import operator, pipe, streamcontext
+from aiostream import operator, pipable_operator, pipe, streamcontext
 
 
 @operator
-async def random(offset=0.0, width=1.0, interval=0.1):
+async def random(
+    offset: float = 0.0, width: float = 1.0, interval: float = 0.1
+) -> AsyncIterator[float]:
     """Generate a stream of random numbers."""
     while True:
         await asyncio.sleep(interval)
         yield offset + width * random_module.random()
 
 
-@operator(pipable=True)
-async def power(source, exponent):
+@pipable_operator
+async def power(
+    source: AsyncIterable[float], exponent: float | int
+) -> AsyncIterator[float]:
     """Raise the elements of an asynchronous sequence to the given power."""
     async with streamcontext(source) as streamer:
         async for item in streamer:
-            yield item ** exponent
+            yield item**exponent
 
 
-@operator(pipable=True)
-def square(source):
+@pipable_operator
+def square(source: AsyncIterable[float]) -> AsyncIterator[float]:
     """Square the elements of an asynchronous sequence."""
     return power.raw(source, 2)
 
 
-async def main():
+async def main() -> None:
     xs = (
         random()  # Stream random numbers
         | square.pipe()  # Square the values
@@ -37,6 +42,4 @@ async def main():
 
 
 # Run main coroutine
-loop = asyncio.get_event_loop()
-loop.run_until_complete(main())
-loop.close()
+asyncio.run(main())
